[master] Added a special case typedef of png_longjmp_ptr for WATCOM.
diff --git a/ANNOUNCE b/ANNOUNCE
index 0fecf7a..fc8ae71 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -39,6 +39,7 @@
   Added -DNO_PNG_SNPRINTF to CFLAGS in scripts/makefile.dj2
   Moved the definition of png_snprintf() outside of the enclosing
     #ifdef blocks in pngconf.h
+  Added a special case typedef of png_longjmp_ptr for WATCOM.
 
 Send comments/corrections/commendations to glennrp at users.sourceforge.net
 or to png-mng-implement at lists.sf.net (subscription required; visit
diff --git a/CHANGES b/CHANGES
index f5a8903..5e90ce0 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2623,6 +2623,7 @@
   Added -DNO_PNG_SNPRINTF to CFLAGS in scripts/makefile.dj2
   Moved the definition of png_snprintf() outside of the enclosing
     #ifdef blocks in pngconf.h
+  Added a special case typedef of png_longjmp_ptr for WATCOM.
 
 Send comments/corrections/commendations to glennrp at users.sourceforge.net
 or to png-mng-implement at lists.sf.net (subscription required; visit
diff --git a/png.h b/png.h
index 6c3874b..efbe77c 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.4.4beta02 - July 12, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *  libpng versions 0.97, January 1998, through 1.4.4beta02 - July 12, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -177,7 +177,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.4.4beta02, July 12, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -289,7 +289,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    July 12, 2010
+ *    July 24, 2010
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -353,7 +353,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.4.4beta02"
 #define PNG_HEADER_VERSION_STRING \
-   " libpng version 1.4.4beta02 - July 12, 2010\n"
+   " libpng version 1.4.4beta02 - July 24, 2010\n"
 
 #define PNG_LIBPNG_VER_SONUM   14
 #define PNG_LIBPNG_VER_DLLNUM  14
@@ -1053,7 +1053,11 @@
  * application must include this before png.h to obtain the definition
  * of jmp_buf.
  */
+#  ifdef __WATCOMC__
+typedef void (*png_longjmp_ptr) PNGARG((jmp_buf, int));
+#  else
 typedef void (PNGAPI *png_longjmp_ptr) PNGARG((jmp_buf, int));
+#  endif
 #endif
 
 /* Transform masks for the high-level interface */
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.4.4beta02 - July 12, 2010
+ * libpng version 1.4.4beta02 - July 24, 2010
  * Copyright (c) 1998-2010 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *  libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *  libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *  libpng versions 0.97, January 1998, through 1.4.4beta02 - July 12, 2010: Glenn
+ *  libpng versions 0.97, January 1998, through 1.4.4beta02 - July 24, 2010: Glenn
  *  See also "Contributing Authors", below.
  *
@@ -177,7 +177,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.4.4beta02, July 12, 2010, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.4.4beta02, July 24, 2010, are
  * Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5